.. highlight:: bash

.. _script_stoolbox:

`stoolbox`
==========

sisl exposes user contributed tool-box command line interfaces through a common
interface.

The `sisl` toolbox is a separate package (shipped together with sisl) which contains
tools that are thought to be good tools for sisl users but are too specialized in
terms of usability to enter the sisl API.

We encourage users to contribute toolboxes to increase visibility and usability.

For a short description of the possible toolboxes do::

   stoolbox --help

For available toolboxes, please see :ref:`Toolboxes <toc-toolbox>`.


Have an idea?
-------------

If you want to contribute or have an idea for a toolbox, feel free to open an issue `here <issue_>`_.


.. highlight:: python
